/** \addtogroup tuePrvTrackMerge
 * @{
 * \file        tue_prv_trackMerge.h
 * \brief       public header for gain estimation
 *
 *
 *
 *
 *          (C) Copyright Tuerme Inc. All rights reserved.
 *
 */

#ifndef TUE_PRV_TRACKMERGE_H
#define TUE_PRV_TRACKMERGE_H

#ifdef __cplusplus
extern "C" {
#endif

/*==================[inclusions]============================================*/
#include "TueObjFusn_TrackableListType.h"
#include "tue_prv_common_types.h" /*uint16, float32*/
#include "TueObjFusn_EgoMotionType.h"
/*==================[macros]================================================*/
/*==================[type definitions]======================================*/
/*==================[forward declarations]==================================*/
/*==================[symbolic constants]====================================*/
/*==================[return codes]==========================================*/
/*==================[functions]=============================================*/

#define ObjFusn_START_SEC_CODE

/**
 * @brief Merging non-fused tracks after running track association algorithm
 * 
 * Postprocessing step to merge camera-only with radar-only traks.
 * It loops through TRK_List and fuses close camera-only and radar-only tracks based
 * on a modified distance, scaled by a factor (taking systematic camera error into account) 
 * Association part is very similar to track association with some changes such as increasing match gate size.
 *
 * @param[in] pEgoMotion pointer to ego vehicle dynamic at current timestamp
 * @param[in,out] pTrackList trackable list (usually internal TRK_LIST)
 * @param[out] abMarkedToDrop boolean array specifying tracks to be dropped
 * after merging tracks
 *
 * @return error status
*/
uint32 trackMerge_mergeTracks(CONSTP2VAR(TueObjFusn_TrackableListType, AUTOMATIC, ObjFusn_VAR_NOINIT) pTrackList,
                              VAR(boolean, ObjFusn_VAR_NOINIT) abMarkedToDrop[],
                              CONSTP2CONST(TueObjFusn_EgoMotionType, AUTOMATIC, ObjFusn_VAR_NOINIT) pEgoMotion);
#define ObjFusn_STOP_SEC_CODE


/*==================[external function declarations]========================*/
/*==================[external constants]====================================*/
/*==================[external data]=========================================*/

#ifdef __cplusplus
}
#endif

#endif /* TUE_PRV_TRACKMERGE_H */
/**
 * @}
 */
/*==================[end of file]===========================================*/
